@@ -9,7 +9,7 @@ type in the associated XML schema.
 from __future__ import absolute_import, print_function
 
 from ..exc import InvalidXmlError
-from ..util import Emu
+from ..util import Centipoints, Emu
 
 
 class BaseSimpleType(object):
@@ -24,6 +24,16 @@ class BaseSimpleType(object):
         str_value = cls.convert_to_xml(value)
         return str_value
 
+    @classmethod
+    def validate_float(cls, value):
+        """
+        Note that int values are accepted.
+        """
+        if not isinstance(value, (int, float)):
+            raise TypeError(
+                "value must be a number, got %s" % type(value)
+            )
+
     @classmethod
     def validate_int(cls, value):
         if not isinstance(value, int):
@@ -31,6 +41,15 @@ class BaseSimpleType(object):
                 "value must be <type 'int'>, got %s" % type(value)
             )
 
+    @classmethod
+    def validate_float_in_range(cls, value, min_inclusive, max_inclusive):
+        cls.validate_float(value)
+        if value < min_inclusive or value > max_inclusive:
+            raise ValueError(
+                "value must be in range %s to %s inclusive, got %s" %
+                (min_inclusive, max_inclusive, value)
+            )
+
     @classmethod
     def validate_int_in_range(cls, value, min_inclusive, max_inclusive):
         cls.validate_int(value)
@@ -583,12 +602,7 @@ class ST_TextFontSize(BaseIntType):
 
     @classmethod
     def validate(cls, value):
-        cls.validate_int(value)
-        if value < 100 or value > 400000:
-            raise ValueError(
-                "value must be in range 100 -> 400000 (1-4000 points), got"
-                " %d" % value
-            )
+        cls.validate_int_in_range(value, 100, 400000)
 
 
 class ST_TextIndentLevelType(BaseIntType):
@@ -598,6 +612,53 @@ class ST_TextIndentLevelType(BaseIntType):
         cls.validate_int_in_range(value, 0, 8)
 
 
+class ST_TextSpacingPercentOrPercentString(BaseFloatType):
+
+    @classmethod
+    def convert_from_xml(cls, str_value):
+        if str_value.endswith('%'):
+            return cls._convert_from_percent_literal(str_value)
+        return int(str_value) / 100000.0
+
+    @classmethod
+    def _convert_from_percent_literal(cls, str_value):
+        float_part = str_value[:-1]  # trim off '%' character
+        percent_value = float(float_part)
+        lines_value = percent_value / 100.0
+        return lines_value
+
+    @classmethod
+    def convert_to_xml(cls, value):
+        """
+        1.75 -> '175000'
+        """
+        lines = value * 100000.0
+        return str(int(round(lines)))
+
+    @classmethod
+    def validate(cls, value):
+        cls.validate_float_in_range(value, 0.0, 132.0)
+
+
+class ST_TextSpacingPoint(BaseIntType):
+
+    @classmethod
+    def convert_from_xml(cls, str_value):
+        """
+        Reads string integer centipoints, returns |Length| value.
+        """
+        return Centipoints(int(str_value))
+
+    @classmethod
+    def convert_to_xml(cls, value):
+        length = Emu(value)  # just to make sure
+        return str(length.centipoints)
+
+    @classmethod
+    def validate(cls, value):
+        cls.validate_int_in_range(value, 0, 20116800)
+
+
 class ST_TextTypeface(XsdString):
     pass
 
