@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from pptx.oxml import parse_xml_bytes
+from pptx.oxml import parse_xml
 
 import pdb
 
@@ -9,6 +9,6 @@ from .unitutil import serialize_xml
 nsmap = 'http://schemas.openxmlformats.org/presentationml/2006/main'
 
 xml = '<p:sp xmlns:p="%s"><p:nvSpPr/></p:sp>' % nsmap
-sp = parse_xml_bytes(xml)
+sp = parse_xml(xml)
 pdb.set_trace()
 msg = 'got:\n\n%s' % serialize_xml(sp)
